﻿using System;
using System.Threading;
using Microsoft.SPOT;
using Microsoft.SPOT.Hardware;
using SecretLabs.NETMF.Hardware.Netduino;

using OutilsRadar;
using ToolBoxes;

namespace Radar
{ /* Documentation sur Github
   * Classe associée à l'afficheur LCD : http://webge.github.io/ELCD162/
   * Classe associée aux PCF8574: http://webge.github.io/PCF8574/
   * Classe associée au télémètre SRF08 : http://webge.github.io/SRF08/ 
   */
    public class Program
    {
        public static void Main()
        {
            byte addLedsI2C = 0x22; // Adresse SLA (7bits) des Leds //0x3A pour PCF8574A ou 0x22
            byte addBPsI2C = 0x23; // Adresse SLA (7bits) des BP // 0x3B pour PCF8574A ou 0x23
            byte addTelemetreI2C = 0x70; // Adresse SLA (7bits) du télémètre à ultrasons
            UInt16 FreqI2C = 100; // Fréquence du bus

            byte increment = 5; // Intervalle de distance en cm => éclairage d'une Led
            LedCard.LEDs LedsOnI2CCard = LedCard.LEDs.All_Off; // Contient la valeur transmise aux Leds
                                                               // Ici Extinction des Leds

            // Construction des objets
            PCF8574 Leds = new PCF8574(addLedsI2C, FreqI2C);
            PCF8574 BPs = new PCF8574(addBPsI2C, FreqI2C);
            SRF08 TelemetreUSI2C = new SRF08(addTelemetreI2C, FreqI2C);
            ELCD162 Lcd = new ELCD162();

            // Initialisation
            Leds.Write((byte)LedsOnI2CCard); // Extinction des leds de la carte
            Lcd.Init(); Lcd.ClearScreen();

            while (true)
            {
                // Lecture des BPs
                UInt16 DSTOP = BPs.Read(); // La valeur réglée avec les BPs [0, 255] donne la distance pour
                                                 // laquelle et en dessous de laquelle toutes les Leds sont éclairées
                // Lecture de la distance entre le capteur et un obstacle
                UInt16 distance = TelemetreUSI2C.ReadRange(SRF08.MeasuringUnits.centimeters_InRangingMode);
                
                // Traitement : détermination du nombre de leds à éclairer sur la carte retourne la valeur à transmettre aux Leds
                LedsOnI2CCard = LedCard.TraiterDistance(increment, DSTOP, distance);

                // Ecriture sur les Leds et sur le LCD
                LedCard.Affiche(LedsOnI2CCard, Leds, Lcd, DSTOP, distance,increment);
                //Debug.Print("Distance= " + distance + " BPs = " + DSTOP);

                Thread.Sleep(1000);               
            }
        }
    }
}
